Exception: NeonRAW::Errors::ExpiredCode

Inherits:
StandardError
  • Object
show all
Defined in:
lib/NeonRAW/errors.rb

Overview

You already received an access token using this code. They’re only good for one use.

Instance Method Summary collapse

Constructor Details

#initialize(msg = 'The code used to get the access token has expired.') ⇒ ExpiredCode

Returns a new instance of ExpiredCode.



238
239
240
# File 'lib/NeonRAW/errors.rb', line 238

def initialize(msg = 'The code used to get the access token has expired.')
  super(msg)
end