Class: NeonRAW::Objects::Thing

Inherits:
Object
  • Object
show all
Defined in:
lib/NeonRAW/objects/thing.rb,
lib/NeonRAW/objects/thing/votable.rb,
lib/NeonRAW/objects/thing/editable.rb,
lib/NeonRAW/objects/thing/gildable.rb,
lib/NeonRAW/objects/thing/saveable.rb,
lib/NeonRAW/objects/thing/inboxable.rb,
lib/NeonRAW/objects/thing/repliable.rb,
lib/NeonRAW/objects/thing/createable.rb,
lib/NeonRAW/objects/thing/refreshable.rb,
lib/NeonRAW/objects/thing/moderateable.rb

Overview

Exists to hold methods that work in all objects.

Defined Under Namespace

Modules: Createable, Editable, Gildable, Inboxable, Moderateable, Refreshable, Repliable, Saveable, Votable

Instance Attribute Summary collapse

Instance Attribute Details

#idString (readonly)

Returns The id of the thing.

Returns:

  • (String)

    The id of the thing.



18
19
20
21
22
# File 'lib/NeonRAW/objects/thing.rb', line 18

class Thing
  class << self
    public :define_method
  end
end

#nameString (readonly)

Returns The fullname of the thing.

Returns:

  • (String)

    The fullname of the thing.



18
19
20
21
22
# File 'lib/NeonRAW/objects/thing.rb', line 18

class Thing
  class << self
    public :define_method
  end
end